Description: Carnivorous plant disscussion, including Venus Fly Trap help, Sundew, pitcher plants and more!
Keywords: Carnivorous plant,Venus fly trap,Venus flytrap,Dionaea,pitcher plant,sarracenia,drosera,sundew, nepenthes

- Register
- Help
- Remember Me?

1. If this is your first visit, be sure to check out the FAQ by clicking the link above. You may have to register before you can post: click the register link above to proceed. To start viewing messages, select the forum that you want to visit from the selection below.

# Terra Forums Carnivorous Plant Discussions

Welcome to the Terra Forums Carnivorous Plant Discussions.

1. ## Announcements! and Articles Of Interest Threads / Posts Last Post

   1. ## Forum Announcements

      Announcements about terraforums.com

      #### Moderators:

      1. adnedarn

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 4
      - Posts: 5

      #### Last Post:

      Terraforums gallery.... ...

      by
      adnedarn
      - View Profile
      - View Forum Posts
      - Visit Homepage

      10-18-2012, 11:16 PM

   2. ## Carnivorous Plant Articles

      Written and edited by knowledgeable CP enthusiasts.

      #### Moderators:

      1. Tamlin Dawnstar

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 22
      - Posts: 49

      #### Last Post:

      Writing Plant Names -...

      by
      Joseph Clemens
      - View Profile
      - View Forum Posts
      - Visit Homepage

      11-12-2014, 11:37 PM

2. ## FlyTrapShop.com Threads / Posts Last Post

   1. ## FlyTrapShop.com

      Info and News about FlyTrapShop.com

      #### Moderators:

      1. adnedarn

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 22
      - Posts: 515

      #### Last Post:

      Nepenthes 'Judith Finn'

      by
      adnedarn
      - View Profile
      - View Forum Posts
      - Visit Homepage

      11-21-2014, 03:32 PM

3. ## General Discussion Threads / Posts Last Post

   1. ## Introduce Yourself!

      Introduce yourself and your interests to the rest of the community.

      #### Moderators:

      1. PlantAKiss,
      2. Not a Number

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 971
      - Posts: 10,203

      #### Last Post:

      It's nice to be back

      by
      Joseph Clemens
      - View Profile
      - View Forum Posts
      - Visit Homepage

      12-04-2014, 10:39 PM

   2. ## General Discussions

      Open forum for any topics of conversation!

      #### Moderators:

      1. adnedarn,
      2. PlantAKiss,
      3. Not a Number

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 13,908
      - Posts: 189,900

      #### Last Post:

      TF Rendezvous in Portland, OR

      by
      bluemax
      - View Profile
      - View Forum Posts

      12-05-2014, 07:38 PM

   3. ## Greenhouses, Terrariums and Bog Gardens

      Maintenance, Care, Building, etc.

      #### Moderators:

      1. nepenthes gracilis,
      2. Joseph Clemens,
      3. adnedarn

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 2,546
      - Posts: 32,265

      #### Last Post:

      HF greenhouse build

      by
      dionae
      - View Profile
      - View Forum Posts

      12-04-2014, 08:15 AM

   4. ## Conservation Station

      Talk here about conservation issues, report findings, rally the troops, save your CP's!

      #### Moderators:

      1. Barry-Rice,
      2. schloaty,
      3. Ozzy

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 270
      - Posts: 3,274

      #### Last Post:

      Petition to stop bulldozing...

      by
      SubRosa
      - View Profile
      - View Forum Posts

      12-01-2014, 03:25 PM

   5. ## North American Sarracenia Conservancy

      U.S. National Sarracenia Collection discussions for all members and organizers.

      #### Moderators:

      1. Ozzy,
      2. PlantAKiss

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 198
      - Posts: 2,693

      #### Last Post:

      NASC

      by
      Ozzy
      - View Profile
      - View Forum Posts
      - Visit Homepage

      12-04-2014, 11:56 AM

   6. ## NASC Benefit Auction 2014

      CLOSED! No more listings or bidding please.

      #### Moderators:

      1. Presto,
      2. Ozzy,
      3. DroseraBug,
      4. Kitkor,
      5. lil hokie,
      6. SRMyers,
      7. kwende

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 133
      - Posts: 1,538

      #### Last Post:

      Seed - Dosera cistiflora Pink...

      by
      Tacks
      - View Profile
      - View Forum Posts

      06-18-2014, 12:57 PM

   7. ## Foreign Carnivorous Plant Resources

      A forum For People Living in the UK, EU, Asia, South America, Canada, Etc.

      #### Moderators:

      1. Alexis,
      2. Cindy

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 342
      - Posts: 3,113

      #### Last Post:

      any south africans?

      by
      Jaco Truter
      - View Profile
      - View Forum Posts

      10-23-2014, 03:16 AM

   8. ## Grow List

      Member Grow Lists

      #### Moderators:

      1. Ozzy,
      2. adnedarn

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 727
      - Posts: 901

      #### Last Post:

      M Jacobs's growlist

      by
      M Jacobs
      - View Profile
      - View Forum Posts

      12-01-2014, 08:02 PM

4. ## Trades and Classifides Threads / Posts Last Post

   This is where you trade, buy, and sell plants!

   1. ## Carnivorous Plant Trading Post

      CP Trades - no sales, or offers to buy please

      #### Moderators:

      1. adnedarn,
      2. schloaty,
      3. Not a Number

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 6,218
      - Posts: 49,083

      #### Last Post:

      Nepenthes boschiana pollen...

      by
      killerplantsguy
      - View Profile
      - View Forum Posts

      12-05-2014, 04:32 PM

   2. ## Terraforums Classifieds

      Thank You members can list items, everyone can buy!

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 12
      - Posts: 34

      #### Last Post:

      Don't forget to leave...

      by
      adnedarn
      - View Profile
      - View Forum Posts
      - Visit Homepage

      11-10-2014, 09:15 PM

   3. ## Looking to buy

      Thank you members post items you would like to buy. Please be as specific as you can.

      #### Sub-Forums:

      1. Looking to buy SOLD!!

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 9
      - Posts: 64

      #### Last Post:

      LTB Drosera capensis varities

      by
      Tacks
      - View Profile
      - View Forum Posts

      11-29-2014, 03:22 AM

5. ## Carnivorous Plant Discussions - Care & General Info Threads / Posts Last Post

   1. ## Venus Flytrap (Dionaea ) Care Information & Tips

      Tips and Hints on Venus Fly Trap care

      #### Moderators:

      1. nepenthes gracilis,
      2. Not a Number

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 3,739
      - Posts: 34,353

      #### Last Post:

      King Henry was hungry

      by
      ps3isawesome
      - View Profile
      - View Forum Posts

      11-27-2014, 12:12 PM

   2. ## Pitcher Plants: (Sarracenia, Heliamphora, Darlingtonia, Cephalotus)

      Various Pitcher Plant Care tips & information

      #### Moderators:

      1. xvart,
      2. Est

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 4,340
      - Posts: 47,588

      #### Last Post:

      Dark Seed Grown Cephalotus...

      by
      Av8tor1
      - View Profile
      - View Forum Posts

      12-05-2014, 07:58 PM

   3. ## Tropical Pitcher Plants (Nepenthes)

      Care tips & information

      #### Moderators:

      1. nepenthes gracilis

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 8,067
      - Posts: 98,077

      #### Last Post:

      Nepenthes villosa

      by
      Av8tor1
      - View Profile
      - View Forum Posts

      12-05-2014, 05:47 PM

   4. ## Sundews (Drosera), Byblis, Drosophyllum

      Care tips & information

      #### Moderators:

      1. Tamlin Dawnstar,
      2. Joseph Clemens,
      3. Not a Number

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 4,777
      - Posts: 42,496

      #### Last Post:

      Rainbows in the Midwest

      by
      DragonsEye
      - View Profile
      - View Forum Posts

      12-03-2014, 05:51 PM

   5. ## Butterwort (Pinguicula)

      Care tips & information

      #### Moderators:

      1. Joseph Clemens,
      2. Not a Number

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 1,587
      - Posts: 13,831

      #### Last Post:

      Flowering Ping

      by
      hcarlton
      - View Profile
      - View Forum Posts

      12-03-2014, 01:27 PM

   6. ## Utricularia, Aldrovanda, Genlisea

      Care tips & information

      #### Moderators:

      1. xvart,
      2. Colieo

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 1,371
      - Posts: 12,019

      #### Last Post:

      Orchidioides Flowers

      by
      RL7836
      - View Profile
      - View Forum Posts

      12-04-2014, 01:37 PM

   7. ## Carnivorous/Quasi-Carnivorous: Bromeliads, Devil's Claw, Roridula, Triphyophyllum

      Care tips & information

      #### Moderators:

      1. xvart,
      2. Est

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 197
      - Posts: 1,816

      #### Last Post:

      Share Your Brocchinia!

      by
      hcarlton
      - View Profile
      - View Forum Posts

      09-24-2014, 07:42 PM

   8. ## Identify That Plant!

      Let the Community identify your unknown Carnivorous Plant!

      #### Moderators:

      1. Ozzy,
      2. nepenthes gracilis,
      3. PlantAKiss

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 1,036
      - Posts: 9,096

      #### Last Post:

      Ping ID, flowers included

      by
      DragonsEye
      - View Profile
      - View Forum Posts

      11-14-2014, 06:04 PM

6. ## Non Carnivorous Plants Discussions Threads / Posts Last Post

   1. ## Orchids

      Care, Grow Tips, General Information

      #### Moderators:

      1. PlantAKiss,
      2. Not a Number

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 627
      - Posts: 5,239

      #### Last Post:

      SHOW US YOUR ORCHIDS/FLOWERS!

      by
      anramitaco
      - View Profile
      - View Forum Posts

      11-21-2014, 04:45 PM

   2. ## Bromeliads, Tillandsia, Ferns

      Care, Information, Tips and Info

      #### Moderators:

      1. xvart,
      2. Est

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 136
      - Posts: 883

      #### Last Post:

      Check out this score of...

      by
      DragonsEye
      - View Profile
      - View Forum Posts

      12-02-2014, 04:54 PM

   3. ## Cactus and other Succulents

      Care, grow tips, general information

      #### Moderators:

      1. xvart,
      2. Est

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 383
      - Posts: 2,568

      #### Last Post:

      Aloe help

      by
      theplantman
      - View Profile
      - View Forum Posts

      11-27-2014, 10:53 AM

   4. ## Miscellaneous Plants

      Open for any type of non-CP you can think of

      #### Moderators:

      1. xvart,
      2. Est

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 708
      - Posts: 4,907

      #### Last Post:

      My Ant Plants

      by
      DragonsEye
      - View Profile
      - View Forum Posts

      12-04-2014, 11:28 AM

7. ## Terrariums, Vivariums, Eco-Spheres, Aquariums, and Animal Life Threads / Posts Last Post

   1. ## Reptiles, Amphibians and other terrarium dwelling animals

      #### Moderators:

      1. Ozzy

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 637
      - Posts: 6,287

      #### Last Post:

      Salamander ID Needed

      by
      DragonsEye
      - View Profile
      - View Forum Posts

      12-04-2014, 08:21 PM

   2. ## Insects, Spiders, and other Arthropods

      And other plant food...errr bugs.

      #### Moderators:

      1. Est,
      2. Presto

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 247
      - Posts: 2,086

      #### Last Post:

      Look Alikes :D

      by
      TongueFlicker
      - View Profile
      - View Forum Posts

      11-17-2014, 08:15 PM

   3. ## Fresh Water Aquariums

      Planted, Fish Only, Cichlid, Species, discuss your fresh water aquaria

      #### Moderators:

      1. Est,
      2. xvart

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 370
      - Posts: 4,503

      #### Last Post:

      Cryptocoryne pontederiifolia...

      by
      RSS
      - View Profile
      - View Forum Posts

      11-15-2014, 06:47 PM

   4. ## Salt Water Aquariums

      Reef, Fish Only, Agressive, Brackish, discuss your saltwater aquaria.

      #### Moderators:

      1. Est,
      2. xvart

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 89
      - Posts: 969

      #### Last Post:

      adnedarn's reef tank....build...

      by
      NemJones
      - View Profile
      - View Forum Posts

      10-07-2014, 10:33 PM

8. ## Old NASC auctions Threads / Posts Last Post

   Old/closed auctions For reference only.

   1. ## 2006 NASC Benefit Auction

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 221
      - Posts: 2,822

      #### Last Post:

      Bugweed Items

      by
      mannyherrera
      - View Profile
      - View Forum Posts

      05-09-2007, 08:14 AM

   2. ## 2007 NASC Benefit Auction

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 163
      - Posts: 2,173

      #### Last Post:

      Jim Miller's Lost World...

      by
      Ozzy
      - View Profile
      - View Forum Posts
      - Visit Homepage

      10-18-2007, 07:42 PM

   3. ## 2008 NASC Benefit Auction

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 204
      - Posts: 2,665

      #### Last Post:

      C. follicularis winnder...

      by
      xvart
      - View Profile
      - View Forum Posts

      10-25-2008, 02:38 PM

   4. ## 2009 NASC Benefit Auction

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 207
      - Posts: 2,392

      #### Last Post:

      Devil Claws - DroseraBug $10

      by
      Ozzy
      - View Profile
      - View Forum Posts
      - Visit Homepage

      07-28-2009, 09:09 PM

   5. ## 2010 NASC Benefit Auction

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 165
      - Posts: 2,233

      #### Last Post:

      D. burmannii "Light Pink...

      by
      theyellowdart
      - View Profile
      - View Forum Posts

      03-02-2011, 02:53 PM

   6. ## 2011 NASC Benefit Auction

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 189
      - Posts: 2,351

      #### Last Post:

      Pygmy Drosera Cthulhu138 15$

      by
      Presto
      - View Profile
      - View Forum Posts

      09-01-2011, 03:45 PM

   7. ## 2012 NASC Benefit Auction

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 219
      - Posts: 2,975

      #### Last Post:

      An important announcement...

      by
      DJ57
      - View Profile
      - View Forum Posts

      10-26-2012, 01:57 PM

   8. ## NASC Benefit Auction 2013

      #### Moderators:

      1. Presto,
      2. Kitkor,
      3. catrus,
      4. lil hokie,
      5. Ozzy,
      6. F R e N c H 3 z,
      7. DroseraBug,
      8. SRMyers

      #### Forum Actions:

      #### Forum Statistics:

      - Threads: 175
      - Posts: 2,089

      #### Last Post:

      Discussion and Requests Here...

      by
      kulamauiman
      - View Profile
      - View Forum Posts
      - Visit Homepage

      03-18-2014, 03:52 PM

Mark Forums Read | View Forum Leaders

## What's Going On?

### Spam-O-Matic Statistics

89684 Spammers Denied Registration

### Today's Birthdays

1. rcl27 (29)

### Terra Forums Carnivorous Plant Discussions Statistics

Threads
  57,433
Posts
  622,137
Members
  5,206
Active Members
  980

Welcome to our newest member, Icarus

### Icon Legend

  Contains unread forum posts
  Contains no unread forum posts
  Forum is a category
  Forum is a Link